@@ -13,8 +13,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 """
 Resource-related interfaces
@@ -121,21 +120,24 @@ class IResourceTypeInformation(Interface):
 
     id = zope.schema.TextLine(
         title=_("Id of the resource type."),
-        description=_("""Used for lookup of named utilities that have resource
-        type specific information."""))
+        description=_(
+            "Used for lookup of named utilities that have resource "
+            "type specific information."))
 
     title = zope.schema.TextLine(
         title=_("The title of a resource type."),
-        description=_("""A string that will be displayed to users in tables or
-        resource type selection widgets."""))
+        description=_(
+            "A string that will be displayed to users in tables or "
+            "resource type selection widgets."))
 
 
 class IResourceFactoryUtility(Interface):
 
     title = zope.schema.TextLine(
         title=_("The title of a resource type."),
-        description=_("""A string that will be displayed to users in tables or
-        resource type selection widgets."""))
+        description=_(
+            "A string that will be displayed to users in tables or "
+            "resource type selection widgets."))
 
     def columns():
         """Default columns for display of this resource in a table."""
